----------------------------------------------------
``change-log`` -- Change and Log project information
----------------------------------------------------

This project provides utilities to manage information about a project
and prepare it for publishing.

``change log``
    dynamically create changelogs from fragment files
